@@ -90,6 +90,17 @@ def read_values_from_array(query_columns_description: list, dis: DataInputStream
         elif dtype == "INTEGER" or dtype == "DATE":
             value_array.append(dis.read_int())
 
-    if len(value_array) < 5:
-        print("stop here")
     return value_array
+
+
+def read_rows_from_batch(query_columns_description: list, dis: DataInputStream) -> list:
+    rows = list()
+    is_row_present = dis.read_byte()
+
+    while is_row_present == 1:
+        if is_row_present:
+            row = read_values_from_array(query_columns_description, dis)
+            rows.append(row)
+        is_row_present = dis.read_byte()
+
+    return rows
