@@ -305,7 +305,7 @@ class Cursor(common.DBAPICursor):
         return self._data
 
     def fetch_batch(self):
-        _logger.info("fetching next batch from e6data")
+        _logger.debug("fetching next batch from e6data")
         client = self.connection.client
         buffer = client.getNextResultBatch(self._query_id)
 
@@ -322,7 +322,6 @@ class Cursor(common.DBAPICursor):
         return self._fetch_all()
 
     def fetchone(self):
-        _logger.info("fetching one")
         if len(self._batch) == 0:
             self.fetch_batch()
             if len(self._batch) == 0:
